AgastDetectorType enum

Inheritance
Available extensions

Values

AGAST_5_8 → const AgastDetectorType
const AgastDetectorType(0)
AGAST_7_12d → const AgastDetectorType
const AgastDetectorType(1)
AGAST_7_12s → const AgastDetectorType
const AgastDetectorType(2)
OAST_9_16 → const AgastDetectorType
const AgastDetectorType(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AgastDetectorType>
A constant List of the values in this enum, in order of their declaration.