AgastFeatureDetector class

AgastFeatureDetector is a wrapper around the cv::AgastFeatureDetector.

Inheritance
Available extensions

Constructors

AgastFeatureDetector.create({int threshold = 10, bool nonmaxSuppression = true, AgastDetectorType type = AgastDetectorType.OAST_9_16})
create (int threshold=10, bool nonmaxSuppression=true, AgastFeatureDetector::DetectorType type=AgastFeatureDetector::OAST_9_16)
factory
AgastFeatureDetector.empty()
returns a new AgastFeatureDetector algorithm
factory
AgastFeatureDetector.fromPointer(AgastFeatureDetectorPtr ptr, [bool attach = true])
factory

Properties

defaultName → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setterinherited
isEmpty → bool
no setteroverride
nonmaxSuppression ↔ bool
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<AgastFeatureDetector>
getter/setter pairinherited
ref → AgastFeatureDetector
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ int
getter/setter pair
type ↔ AgastDetectorType
getter/setter pair

Methods

detect(Mat src, {VecKeyPoint? keypoints, Mat? mask}) → VecKeyPoint
Detect keypoints in an image using AgastFeatureDetector.
override
detectAndCompute(Mat src, Mat mask, {VecKeyPoint? keypoints, Mat? descriptors, bool useProvidedKeypoints = false}) → (VecKeyPoint, Mat)
override
detectAndComputeAsync(Mat src, Mat mask, {Mat? descriptors, VecKeyPoint? keypoints, bool useProvidedKeypoints = false}) → Future<(VecKeyPoint, Mat)>

Available on AgastFeatureDetector, provided by the AgastFeatureDetectorAsync extension

DetectAndCompute keypoints and compute in an image using AKAZE.
detectAsync(Mat src, {VecKeyPoint? keypoints, Mat? mask}) → Future<VecKeyPoint>

Available on AgastFeatureDetector, provided by the AgastFeatureDetectorAsync extension

Detect keypoints in an image using AgastFeatureDetector.
dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final