CharucoDetector class

Inheritance
Available extensions

Constructors

CharucoDetector.create(CharucoBoard board, CharucoDetectorParameters? charucoParameters, {ArucoDetectorParameters? detectorParameters, ArucoRefineParameters? refineParameters})
factory
CharucoDetector.fromBoard(CharucoBoard board)
factory
CharucoDetector.fromPointer(CharucoDetectorPtr ptr, [bool attach = true])
factory

Properties

board CharucoBoard
getter/setter pair
charucoParameters CharucoDetectorParameters
getter/setter pair
detectorParameters ArucoDetectorParameters
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this object has been disposed.
no setterinherited
props List<Object?>
no setterinherited
ptr Pointer<CharucoDetector>
getter/setter pairinherited
ref → CharucoDetector
no setteroverride
refineParameters ArucoRefineParameters
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectBoard(InputArray image, {VecVecPoint2f? markerCorners, VecI32? markerIds}) → (VecPoint2f, VecI32, VecVecPoint2f, VecI32)
detectBoardAsync(InputArray image, {VecVecPoint2f? markerCorners, VecI32? markerIds}) Future<(VecPoint2f, VecI32, VecVecPoint2f, VecI32)>

Available on CharucoDetector, provided by the CharucoDetectorAsync extension

detectDiamonds(InputArray image, {VecVecPoint2f? markerCorners, VecI32? markerIds}) → (VecVecPoint2f, VecVec4i, VecVecPoint2f, VecI32)
detectDiamondsAsync(InputArray image, {VecVecPoint2f? markerCorners, VecI32? markerIds}) Future<(VecVecPoint2f, VecVec4i, VecVecPoint2f, VecI32)>

Available on CharucoDetector, provided by the CharucoDetectorAsync extension

dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

finalizer NativeFinalizer
final