CvException class

Implemented types

Constructors

CvException(int code, {String msg = "", String err = "", String file = "", String func = "", int line = -1})

Properties

code ↔ ErrorCode
getter/setter pair
err ↔ String
getter/setter pair
file ↔ String
getter/setter pair
func ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
line ↔ int
getter/setter pair
msg ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited