EdgeBoxes class

Inheritance

Constructors

EdgeBoxes({double alpha = 0.65, double beta = 0.75, double eta = 1, double minScore = 0.01, int maxBoxes = 10000, double edgeMinMag = 0.1, double edgeMergeThr = 0.5, double clusterMinMag = 0.5, double maxAspectRatio = 3, double minBoxArea = 1000, double gamma = 2, double kappa = 1.5})
https://docs.opencv.org/4.x/dd/d65/classcv_1_1ximgproc_1_1EdgeBoxes.html#details
factory
EdgeBoxes.fromPointer(Pointer<EdgeBoxes> ptr, [bool attach = true])

Properties

alpha ↔ double
getter/setter pair
beta ↔ double
getter/setter pair
clusterMinMag ↔ double
getter/setter pair
edgeMergeThr ↔ double
getter/setter pair
edgeMinMag ↔ double
getter/setter pair
eta ↔ double
getter/setter pair
gamma ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setterinherited
kappa ↔ double
getter/setter pair
maxAspectRatio ↔ double
getter/setter pair
maxBoxes ↔ int
getter/setter pair
minBoxArea ↔ double
getter/setter pair
minScore ↔ double
getter/setter pair
props → List<num>
no setteroverride
ptr ↔ Pointer<EdgeBoxes>
getter/setter pairinherited
ref → EdgeBoxes
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
getBoundingBoxes(InputArray edge_map, InputArray orientation_map) → (VecRect, VecF32)
Returns array containing proposal boxes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final