ImgHashBase class abstract

Constructors

ImgHashBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compare(InputArray hashOne, InputArray hashTwo) → double
compareAsync(InputArray hashOne, InputArray hashTwo) → Future<double>
compute(InputArray inputArr, [OutputArray? outputArr]) → Mat
computeAsync(InputArray inputArr) → Future<Mat>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited