KalmanFilter class

KalmanFilter implements a standard Kalman filter http://en.wikipedia.org/wiki/Kalman_filter. However, you can modify transitionMatrix, controlMatrix, and measurementMatrix to get an extended Kalman filter functionality.

For further details, please see: https://docs.opencv.org/4.6.0/dd/d6a/classcv_1_1KalmanFilter.html

Inheritance
Available extensions

Constructors

KalmanFilter(KalmanFilterPtr ptr, [bool attach = true])
KalmanFilter.create(int dynamParams, int measureParams, {int controlParams = 0, int type = MatType.CV_32F})
factory

Properties

controlMatrix ↔ Mat
getter/setter pair
errorCovPost ↔ Mat
getter/setter pair
errorCovPre ↔ Mat
getter/setter pair
gain ↔ Mat
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setterinherited
measurementMatrix ↔ Mat
getter/setter pair
measurementNoiseCov ↔ Mat
getter/setter pair
processNoiseCov ↔ Mat
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<KalmanFilter>
getter/setter pairinherited
ref → KalmanFilter
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statePost ↔ Mat
getter/setter pair
statePre ↔ Mat
getter/setter pair
temp1 → Mat
no setter
temp2 → Mat
no setter
temp3 → Mat
no setter
temp4 → Mat
no setter
temp5 → Mat
no setter
transitionMatrix ↔ Mat
getter/setter pair

Methods

correct(Mat measurement) → Mat
correctAsync(Mat measurement) → Future<Mat>

Available on KalmanFilter, provided by the KalmanFilterAsync extension

dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
init(int dynamParams, int measureParams, {int controlParams = 0, int type = MatType.CV_32F}) → void
initAsync(int dynamParams, int measureParams, {int controlParams = 0, int type = MatType.CV_32F}) → Future<void>

Available on KalmanFilter, provided by the KalmanFilterAsync extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict({Mat? control}) → Mat
predictAsync({Mat? control}) → Future<Mat>

Available on KalmanFilter, provided by the KalmanFilterAsync extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final