LineSegmentDetector class

Inheritance

Constructors

LineSegmentDetector({int refine = LineSegmentDetector.REFINE_NONE, double scale = 0.8, double sigmaScale = 0.6, double quant = 2.0, double angTh = 22.5, double logEps = 0, double densityTh = 0.7, int nBins = 1024})
Creates a smart pointer to a LineSegmentDetector object and initializes it.
factory
LineSegmentDetector.create({int refine = LineSegmentDetector.REFINE_NONE, double scale = 0.8, double sigmaScale = 0.6, double quant = 2.0, double angTh = 22.5, double logEps = 0, double densityTh = 0.7, int nBins = 1024})
Creates a smart pointer to a LineSegmentDetector object and initializes it.
factory
LineSegmentDetector.empty()
factory
LineSegmentDetector.fromPointer(LineSegmentDetectorPtr ptr)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
no setterinherited
ptr Pointer<LineSegmentDetector>
getter/setter pairinherited
ref → LineSegmentDetector
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareSegments(InputArray image, (int, int) size, VecVec4f lines1, VecVec4f lines2, {Mat? imageOut}) → (int, Mat)
Draws two groups of lines in blue and red, counting the non overlapping (mismatching) pixels.
detect(InputArray image, {VecVec4f? lines, VecF64? width, VecF64? prec, VecF64? nfa}) → (VecVec4f, VecF64, VecF64, VecF64)
Finds lines in the input image.
detectAsync(InputArray image, {VecVec4f? lines, VecF64? width, VecF64? prec, VecF64? nfa}) Future<(VecVec4f, VecF64, VecF64, VecF64)>
Finds lines in the input image.
dispose() → void
drawSegments(InputArray image, VecVec4f lines) → void
Draws the line segments on a given image.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

finalizer NativeFinalizer
final

Constants

REFINE_ADV → const int
Advanced refinement. Number of false alarms is calculated, lines are refined through increase of precision, decrement in size, etc.
REFINE_NONE → const int
No refinement applied.
REFINE_STD → const int
Standard refinement is applied. E.g. breaking arches into smaller straighter line approximations.