drawSegments method

void drawSegments(
  1. InputArray image,
  2. VecVec4f lines
)

Draws the line segments on a given image.

Parameters - image The image, where the lines will be drawn. Should be bigger or equal to the image, where the lines were found. - lines A vector of the lines that needed to be drawn.

https://docs.opencv.org/4.x/db/d73/classcv_1_1LineSegmentDetector.html#aff3fef3cc44188e264e0d27ee6312be2

Implementation

void drawSegments(InputArray image, VecVec4f lines) {
  cvRun(() => cimgproc.cv_LineSegmentDetector_drawSegments(ref, image.ref, lines.ref, ffi.nullptr));
}