MSER class

MSER is a wrapper around the cv::MSER.

Inheritance
Available extensions

Constructors

MSER.create({int delta = 5, int minArea = 60, int maxArea = 14400, double maxVariation = 0.25, double minDiversity = 0.2, int maxEvolution = 200, double areaThreshold = 1.01, double minMargin = 0.003, int edgeBlurSize = 5})
Full constructor for %MSER detector
factory
MSER.empty()
returns a new MSER algorithm
factory
MSER.fromPointer(MSERPtr ptr, [bool attach = true])
factory

Properties

areaThreshold ↔ double
getter/setter pair
defaultName → String
no setteroverride
delta ↔ int
getter/setter pair
edgeBlurSize ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setterinherited
isEmpty → bool
no setteroverride
maxArea ↔ int
getter/setter pair
maxEvolution ↔ int
getter/setter pair
maxVariation ↔ double
getter/setter pair
minArea ↔ int
getter/setter pair
minDiversity ↔ double
getter/setter pair
minMargin ↔ double
getter/setter pair
pass2Only ↔ bool
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<MSER>
getter/setter pairinherited
ref → MSER
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(Mat src, {VecKeyPoint? keypoints, Mat? mask}) → VecKeyPoint
Detect keypoints in an image using MSER.
override
detectAndCompute(Mat src, Mat mask, {VecKeyPoint? keypoints, Mat? descriptors, bool useProvidedKeypoints = false}) → (VecKeyPoint, Mat)
override
detectAndComputeAsync(Mat src, Mat mask, {Mat? descriptors, VecKeyPoint? keypoints, bool useProvidedKeypoints = false}) → Future<(VecKeyPoint, Mat)>

Available on MSER, provided by the MSERAsync extension

DetectAndCompute keypoints and compute in an image using AKAZE.
detectAsync(Mat src, {VecKeyPoint? keypoints, Mat? mask}) → Future<VecKeyPoint>

Available on MSER, provided by the MSERAsync extension

Detect keypoints in an image using MSER.
dispose() → void
Releases the underlying native resources. Idempotent: calling it more than once is safe, but the object must not be used after dispose.
inherited
freeNative() → void
Frees the native resources owned by this object. Subclasses implement the concrete free logic here; callers must use dispose instead.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final