MatType extension type

on
Implemented types

Constructors

MatType(int value)
const
MatType.CV_8SC(int channels)
const
MatType.CV_8UC(int channels)
const
MatType.CV_16FC(int channels)
const
MatType.CV_16SC(int channels)
const
MatType.CV_16UC(int channels)
const
MatType.CV_32FC(int channels)
const
MatType.CV_32SC(int channels)
const
MatType.CV_64FC(int channels)
const
MatType.makeType(int depth, int channels)
const

Properties

channels → int
no setter
depth → int
no setter
elemSize → int
no setter
elemSize1 → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInteger → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

asString() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CV_8S → const int
CV_8SC1 → const MatType
CV_8SC2 → const MatType
CV_8SC3 → const MatType
CV_8SC4 → const MatType
CV_8U → const int
CV_8UC1 → const MatType
predefined type constants
CV_8UC2 → const MatType
CV_8UC3 → const MatType
CV_8UC4 → const MatType
CV_16F → const int
CV_16FC1 → const MatType
CV_16FC2 → const MatType
CV_16FC3 → const MatType
CV_16FC4 → const MatType
CV_16S → const int
CV_16SC1 → const MatType
CV_16SC2 → const MatType
CV_16SC3 → const MatType
CV_16SC4 → const MatType
CV_16U → const int
CV_16UC1 → const MatType
CV_16UC2 → const MatType
CV_16UC3 → const MatType
CV_16UC4 → const MatType
CV_32F → const int
CV_32FC1 → const MatType
CV_32FC2 → const MatType
CV_32FC3 → const MatType
CV_32FC4 → const MatType
CV_32S → const int
CV_32SC1 → const MatType
CV_32SC2 → const MatType
CV_32SC3 → const MatType
CV_32SC4 → const MatType
CV_64F → const int
CV_64FC1 → const MatType
CV_64FC2 → const MatType
CV_64FC3 → const MatType
CV_64FC4 → const MatType
CV_CN_MAX → const int
CV_CN_SHIFT → const int
CV_DEPTH_MAX → const int
CV_MAT_DEPTH_MASK → const int