Point2f class

Inheritance

Constructors

Point2f(double x, double y)
factory
Point2f.fromNative(CvPoint2f p)
factory
Point2f.fromPointer(Pointer<CvPoint2f> ptr, [bool attach = true])

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<double>
no setteroverride
ptr ↔ Pointer<CvPoint2f>
getter/setter pairinherited
ref → CvPoint2f
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final