Point3f class

Inheritance

Constructors

Point3f(double x, double y, double z)
factory
Point3f.fromNative(CvPoint3f p)
factory
Point3f.fromPointer(Pointer<CvPoint3f> ptr, [bool attach = true])

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<double>
no setteroverride
ptr ↔ Pointer<CvPoint3f>
getter/setter pairinherited
ref → CvPoint3f
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair
z ↔ double
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final