Stitcher class
High level image stitcher.
It's possible to use this class without being aware of the entire stitching pipeline. However, to be able to achieve higher stitching stability and quality of the final images at least being familiar with the theory is recommended. https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#details
- Inheritance
- Available extensions
Constructors
- Stitcher.create({StitcherMode mode = StitcherMode.PANORAMA})
-
Creates a Stitcher configured in one of the stitching modes.
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a308a47865a1f381e4429c8ec5e99549f
factory
- Stitcher.fromPointer(StitcherPtr ptr, [bool attach = true])
-
factory
Properties
- component → VecI32
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a7fed80561a9b46a1a924ac6cb334ac85
no setter
- compositingResol ↔ double
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#ad13d2d50b253e471fbaf041b9a044571
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpolationFlags ↔ int
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#abc0c8f54a1d223a1098206654813d973
getter/setter pair
- isDisposed → bool
-
Whether this object has been disposed.
no setterinherited
- panoConfidenceThresh ↔ double
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a3755bbeca7f4c80dc42af034f7621568
getter/setter pair
-
props
→ List<
Object?> -
no setterinherited
-
ptr
↔ Pointer<
Stitcher> -
getter/setter pairinherited
- ref → Stitcher
-
no setteroverride
- registrationResol ↔ double
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a9b90774eabdf68c9ee864918d620538d
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seamEstimationResol ↔ double
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#ac559c3eb228614f9402ff3eba23a08f5
getter/setter pair
- waveCorrection ↔ bool
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#af6a51e0b23dac119a3612d57345f9a7f
getter/setter pair
- waveCorrectKind ↔ int
-
https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#ad9c9c9b8a97b686ad3b93f7918c4c6de
getter/setter pair
Methods
-
composePanorama(
{VecMat? images}) → (StitcherStatus, Mat) - These functions try to compose the given images (or images stored internally from the other function calls) into the final pano under the assumption that the image transformations were estimated before. https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#acc8409a6b2e548de1653f0dc5c2ccb02
-
composePanoramaAsync(
{VecMat? images}) → Future< (StitcherStatus, Mat)> -
Available on Stitcher, provided by the StitcherAsync extension
-
dispose(
) → void -
Releases the underlying native resources. Idempotent: calling it more
than once is safe, but the object must not be used after dispose.
inherited
-
estimateTransform(
VecMat images, {VecMat? masks}) → StitcherStatus - These functions try to match the given images and to estimate rotations of each camera. https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a4c25557af4d40a79a4d1f23d9548131d
-
estimateTransformAsync(
VecMat images, {VecMat? masks}) → Future< StitcherStatus> -
Available on Stitcher, provided by the StitcherAsync extension
-
freeNative(
) → void -
Frees the native resources owned by this object. Subclasses implement the
concrete free logic here; callers must use dispose instead.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stitch(
VecMat images, {VecMat? masks}) → (StitcherStatus, Mat) - This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts. https://docs.opencv.org/4.x/d2/d8d/classcv_1_1Stitcher.html#a37ee5bacf229e9d0fb9f97c8f5ed1acd
-
stitchAsync(
VecMat images, {VecMat? masks}) → Future< (StitcherStatus, Mat)> -
Available on Stitcher, provided by the StitcherAsync extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- finalizer → NativeFinalizer
-
final