VecCharIterator class

Inheritance

Constructors

VecCharIterator(Int8List dataView)

Properties

current → int
The current element.
no setterinherited
currentIndex ↔ int
getter/setter pairinherited
dataView ↔ Int8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveNext() → bool
Advances the iterator to the next element of the iteration.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int idx) → int
override