VecRectIterator class

Inheritance

Constructors

VecRectIterator(VecRectPtr ptr)

Properties

current → Rect
The current element.
no setterinherited
currentIndex ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setteroverride
ptr ↔ Pointer<VecRect>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveNext() → bool
Advances the iterator to the next element of the iteration.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int idx) → Rect
override