drawSegments method
Draws the line segments on a given image.
Parameters - image The image, where the lines will be drawn. Should be bigger or equal to the image, where the lines were found. - lines A vector of the lines that needed to be drawn.
Implementation
void drawSegments(InputArray image, VecVec4f lines) {
cvRun(() => cimgproc.cv_LineSegmentDetector_drawSegments(ref, image.ref, lines.ref, ffi.nullptr));
}