Get the data pointer of the Mat
DO NOT free the pointer, the native memory is managed by Mat. The pointer is only valid while this Mat is alive and its buffer is not reallocated.
ffi.Pointer<U8> get dataPtr => ccore.cv_Mat_data(ref).cast<U8>();