Rect class

Inheritance

Constructors

Rect(int x, int y, int width, int height)
factory
Rect.fromNative(CvRect p)
factory
Rect.fromPointer(Pointer<CvRect> ptr, [bool attach = true])
factory

Properties

bottom → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
props → List<int>
no setteroverride
ptr ↔ Pointer<CvRect>
getter/setter pairinherited
ref → CvRect
no setteroverride
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final