VideoIORegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
enumerateCameras(
VideoCaptureAPIs apiPreference, {int maxCameras = 10}) → List< CameraInfo> -
getBackends(
) → List< VideoCaptureAPIs> - Returns list of all available backends
-
getCameraBackends(
) → List< VideoCaptureAPIs> -
Returns list of available backends which works via
cv::VideoCapture(int index) -
getStreamBackends(
) → List< VideoCaptureAPIs> -
Returns list of available backends which works via
cv::VideoCapture(filename) -
getStreamBufferedBackends(
) → List< VideoCaptureAPIs> -
Returns list of available backends which works via
cv::VideoCapture(buffer) -
getWriterBackends(
) → List< VideoCaptureAPIs> -
Returns list of available backends which works via
cv::VideoWriter() -
hasBackend(
VideoCaptureAPIs api) → bool - Returns true if backend is available
-
isBackendBuiltIn(
VideoCaptureAPIs api) → bool - Returns true if backend is built in (false if backend is used as plugin)
-
parseFrameFormat(
int frameFormat) → String - Parses frame format from int to string